@@ -9,9 +9,8 @@ logger = logging.getLogger(__name__)
 
 class AWSConnection(object):
 
-    def __init__(self, aws_access_key_id=None,
-                 aws_secret_access_key=None,
-                 aws_session_token=None):
+    def __init__(self, aws_access_key_id=None, aws_secret_access_key=None, aws_session_token=None,
+                 use_env_token=True):
 
         # Order of operations for searching for keys:
         #   1. Look for keys passed as kwargs
@@ -24,7 +23,8 @@ class AWSConnection(object):
             # The AWS session token isn't needed most of the time, so we'll check
             # for the env variable here instead of requiring it to be passed
             # whenever the aws_access_key_id and aws_secret_access_key are passed.
-            if aws_session_token is None:
+
+            if aws_session_token is None and use_env_token:
                 aws_session_token = os.getenv('AWS_SESSION_TOKEN')
 
             self.session = boto3.Session(aws_access_key_id=aws_access_key_id,
