@@ -122,7 +122,8 @@ class RedshiftCopyTable(object):
             aws_access_key_id,
             aws_secret_access_key)
 
-    def temp_s3_copy(self, tbl, aws_access_key_id=None, aws_secret_access_key=None):
+    def temp_s3_copy(self, tbl, aws_access_key_id=None, aws_secret_access_key=None,
+                     csv_encoding='utf-8'):
 
         if not self.s3_temp_bucket:
             raise KeyError(("Missing S3_TEMP_BUCKET, needed for transferring data to Redshift. "
@@ -138,10 +139,12 @@ class RedshiftCopyTable(object):
 
         hashed_name = hash(time.time())
         key = f"{S3_TEMP_KEY_PREFIX}/{hashed_name}.csv.gz"
+        if self.s3_temp_bucket_prefix:
+            key = self.s3_temp_bucket_prefix + '/' + key
 
         # Convert table to compressed CSV file, to optimize the transfers to S3 and to
         # Redshift.
-        local_path = tbl.to_csv(temp_file_compression='gzip')
+        local_path = tbl.to_csv(temp_file_compression='gzip', encoding=csv_encoding)
         # Copy table to bucket
         self.s3.put_file(self.s3_temp_bucket, key, local_path)
 
