@@ -1,4 +1,5 @@
 # Adapted from Gmail API tutorial https://developers.google.com/gmail/api
+from abc import ABC, abstractmethod
 from email.mime.text import MIMEText
 from email.mime.multipart import MIMEMultipart
 from email.mime.image import MIMEImage
@@ -24,14 +25,30 @@ import os
 logger = logging.getLogger(__name__)
 
 
-class SendMail(object):
+class SendMail(ABC):
     """SendMail base class for sending emails.
+
+    This class is not designed to be used directly,
+    as it has useful methods for composing messages and validating emails
+    but does not contain all the required functionality in order
+    to send a message. Rather it should be subclassed for each different type of
+    email service, and those subclasses should define an __init__
+    method (to set any instance attributes such as credentials) and a _send_message
+    method (to implement the actual sending of the message).
+
+    For an example of this subclassing in practice, look at the Gmail notification
+    connector in parsons.notifications.gmail.
     """
 
     log = logger
 
+    @abstractmethod
+    def __init__(self, *args, **kwargs):
+        pass
+
+    @abstractmethod
     def _send_message(self, message):
-        raise NotImplementedError("_send_message must be implemented for send_email to run")
+        pass
 
     def _create_message_simple(self, sender, to, subject, message_text):
         """Create a text-only message for an email.
