@@ -1,17 +1,27 @@
-import requests
+"""
+Routines for interacting with TargetSmart's developer API.
+
+https://docs.targetsmart.com/developers/tsapis/v2/index.html
+"""
+import logging
+
 import petl
+import requests
 from parsons.etl.table import Table
 from parsons.utilities import check_env
 
-URI = 'https://api.targetsmart.com/'
+from .targetsmart_smartmatch import SmartMatch
+
+URI = "https://api.targetsmart.com/"
+
+logger = logging.getLogger(__name__)
 
 
-class TargetSmartConnector(object):
-
+class TargetSmartConnector:
     def __init__(self, api_key):
         self.uri = URI
-        self.api_key = check_env.check('TS_API_KEY', api_key)
-        self.headers = {'x-api-key': self.api_key}
+        self.api_key = check_env.check("TS_API_KEY", api_key)
+        self.headers = {"x-api-key": self.api_key}
 
     def request(self, url, args=None, raw=False):
 
@@ -22,16 +32,15 @@ class TargetSmartConnector(object):
 
             return r.json()
 
-        return Table(r.json()['output'])
+        return Table(r.json()["output"])
 
 
-class Person(object):
-
+class Person:
     def __init__(self):
 
         return None
 
-    def data_enhance(self, search_id, search_id_type='voterbase', state=None):
+    def data_enhance(self, search_id, search_id_type="voterbase", state=None):
         """
         Searches for a record based on an id or phone or email address
 
@@ -39,7 +48,7 @@ class Person(object):
             search_id: str
                 The primary key or email address or phone number
             search_id_type: str
-                One of ``voterbase``, ``exacttrack``, ``abilitec_consumer_link``, ``phone``,
+                One of ``voterbase``, ``exacttrack``, ``phone``,
                 ``email``, ``smartvan``, ``votebuilder``, ``voter``, ``household``.
             state: str
                 Two character state code. Required if ``search_id_type`` of ``smartvan``,
@@ -49,37 +58,65 @@ class Person(object):
                 See :ref:`parsons-table` for output options.
         """
 
-        if search_id_type in ['smartvan', 'votebuilder', 'voter'] and state is None:
+        if search_id_type in ["smartvan", "votebuilder", "voter"] and state is None:
 
-            raise KeyError("Search ID type '{}' requires state kwarg".format(search_id_type))
+            raise KeyError(
+                "Search ID type '{}' requires state kwarg".format(search_id_type)
+            )
 
-        if search_id_type not in ('voterbase', 'exacttrack', 'abilitec_consumer_link', 'phone',
-                                  'email', 'smartvan', 'votebuilder', 'voter', 'household'):
+        if search_id_type not in (
+            "voterbase",
+            "exacttrack",
+            "phone",
+            "email",
+            "smartvan",
+            "votebuilder",
+            "voter",
+            "household",
+        ):
 
-            raise ValueError('Search_id_type is not valid')
+            raise ValueError("Search_id_type is not valid")
 
-        url = self.connection.uri + 'person/data-enhance'
+        url = self.connection.uri + "person/data-enhance"
 
-        args = {'search_id': search_id,
-                'search_id_type': search_id_type,
-                'state': state
-                }
+        args = {
+            "search_id": search_id,
+            "search_id_type": search_id_type,
+            "state": state,
+        }
 
         return self.connection.request(url, args=args)
 
-    def radius_search(self, first_name, last_name, middle_name=None, name_suffix=None,
-                      latitude=None, longitude=None, address=None, radius_size=10,
-                      radius_unit='miles', max_results=10, gender='a', age_min=None, age_max=None,
-                      composite_score_min=1, composite_score_max=100, last_name_exact=True,
-                      last_name_is_prefix=False, last_name_prefix_length=10):
+    def radius_search(
+        self,
+        first_name,
+        last_name,
+        middle_name=None,
+        name_suffix=None,
+        latitude=None,
+        longitude=None,
+        address=None,
+        radius_size=10,
+        radius_unit="miles",
+        max_results=10,
+        gender="a",
+        age_min=None,
+        age_max=None,
+        composite_score_min=1,
+        composite_score_max=100,
+        last_name_exact=True,
+        last_name_is_prefix=False,
+        last_name_prefix_length=10,
+        address_type="reg",
+    ):
         """
         Search for a person based on a specified radius
 
         `Args`:
             first_name: str
-                One or more alpha characters
+                One or more alpha characters. Required
             last_name: str
-                One or more alpha characters
+                One or more alpha characters. Required
             middle_name: str
                 One or more alpha characters
             name_suffix: str
@@ -92,6 +129,8 @@ class Person(object):
                 Any geocode-able address
             address_type: str
                 ``reg`` for registration (default) or ``tsmart`` for TargetSmart
+            radius_size: int
+                A positive integer where combined with ``radius_unit`` does not exceed 120 miles
             radius_unit: str
                 One of ``meters``, ``feet``, ``miles`` (default), or ``kilometers``.
             max_results: int
@@ -129,36 +168,46 @@ class Person(object):
         """
 
         if (latitude is None or longitude is None) and address is None:
-            raise ValueError('Lat/Long or Address required')
+            raise ValueError("Lat/Long or Address required")
+
+        if not first_name:
+            raise ValueError("First name is required")
+
+        if not last_name:
+            raise ValueError("Last name is required")
 
         # Convert booleans
         for a in [last_name_exact, last_name_is_prefix]:
             a = str(a)
 
-        url = self.connection.uri + 'person/radius-search'
+        url = self.connection.uri + "person/radius-search"
 
-        args = {'first_name': first_name,
-                'last_name': last_name,
-                'middle_name': middle_name,
-                'name_suffix': name_suffix,
-                'latitude': latitude,
-                'longitude': longitude,
-                'address': address,
-                'radius_size': radius_size,
-                'radius_unit': radius_unit,
-                'max_results': max_results,
-                'gender': gender,
-                'age_min': age_min,
-                'age_max': age_max,
-                'composite_score_min': composite_score_min,
-                'composite_score_max': composite_score_max,
-                'last_name_exact': last_name_exact,
-                'last_name_is_prefix': last_name_is_prefix,
-                'last_name_prefix_length': last_name_prefix_length
-                }
+        args = {
+            "first_name": first_name,
+            "last_name": last_name,
+            "middle_name": middle_name,
+            "name_suffix": name_suffix,
+            "latitude": latitude,
+            "longitude": longitude,
+            "address": address,
+            "address_type": address_type,
+            "radius_size": radius_size,
+            "radius_unit": radius_unit,
+            "max_results": max_results,
+            "gender": gender,
+            "age_min": age_min,
+            "age_max": age_max,
+            "composite_score_min": composite_score_min,
+            "composite_score_max": composite_score_max,
+            "last_name_exact": last_name_exact,
+            "last_name_is_prefix": last_name_is_prefix,
+            "last_name_prefix_length": last_name_prefix_length,
+        }
 
         r = self.connection.request(url, args=args, raw=True)
-        return Table([itm for itm in r['output']]).unpack_dict('data_fields', prepend=False)
+        return Table([itm for itm in r["output"]]).unpack_dict(
+            "data_fields", prepend=False
+        )
 
     def phone(self, table):
         """
@@ -173,21 +222,28 @@ class Person(object):
             See :ref:`parsons-table` for output options.
         """
 
-        url = self.connection.uri + 'person/phone-search'
+        url = self.connection.uri + "person/phone-search"
 
-        args = {'phones': list(petl.values(table.table, 0))}
+        args = {"phones": list(petl.values(table.table, 0))}
 
-        return Table(self.connection.request(url, args=args, raw=True)['result'])
+        return Table(self.connection.request(url, args=args, raw=True)["result"])
 
 
-class Service(object):
-
+class Service:
     def __init__(self):
 
         return None
 
-    def district(self, search_type='zip', address=None, zip5=None, zip4=None, state=None,
-                 latitude=None, longitude=None):
+    def district(
+        self,
+        search_type="zip",
+        address=None,
+        zip5=None,
+        zip4=None,
+        state=None,
+        latitude=None,
+        longitude=None,
+    ):
         """
         Return district information based on a geographic point. The method allows you to
         search based on the following:
@@ -197,7 +253,7 @@ class Service(object):
             :header-rows: 1
 
             * - Search Type
-              - Search Type Name
+              - ``search_type``
               - Required kwarg(s)
             * - Zip Code
               - ``zip``
@@ -206,7 +262,7 @@ class Service(object):
               - ``address``
               - ``address``
             * - Point
-              - point
+              - ``point``
               - ``latitude``, ``longitude``
 
         `Args`:
@@ -223,53 +279,65 @@ class Service(object):
                 The two character state code
             latitude: float or str
                 Valid latitude floating point
-            lontitude: float or str
+            longitude: float or str
                 Valid longitude floating point
         `Returns`:
             Parsons Table
                 See :ref:`parsons-table` for output options.
         """
 
-        if search_type == 'zip' and None in [zip5, zip4]:
+        if search_type == "zip" and None in [zip5, zip4]:
             raise ValueError("Search type 'zip' requires 'zip5' and 'zip4' arguments")
 
-        elif search_type == 'point' and None in [latitude, longitude]:
-            raise ValueError("Search type 'point' requires 'latitude' and 'longitude' arguments")
+        elif search_type == "point" and None in [latitude, longitude]:
+            raise ValueError(
+                "Search type 'point' requires 'latitude' and 'longitude' arguments"
+            )
 
-        elif search_type == 'address' and None in [address]:
+        elif search_type == "address" and None in [address]:
             raise ValueError("Search type 'address' requires 'address' argument")
 
-        elif search_type not in ['zip', 'point', 'address']:
+        elif search_type not in ["zip", "point", "address"]:
             raise KeyError("Invalid 'search_type' provided. ")
 
         else:
             pass
 
-        url = self.connection.uri + 'service/district'
+        url = self.connection.uri + "service/district"
 
-        args = {'search_type': search_type,
-                'address': address,
-                'zip5': zip5,
-                'zip4': zip4,
-                'state': state,
-                'latitude': latitude,
-                'longitude': longitude
-                }
+        args = {
+            "search_type": search_type,
+            "address": address,
+            "zip5": zip5,
+            "zip4": zip4,
+            "state": state,
+            "latitude": latitude,
+            "longitude": longitude,
+        }
 
-        return Table([self.connection.request(url, args=args, raw=True)['match_data']])
+        return Table([self.connection.request(url, args=args, raw=True)["match_data"]])
 
 
 class Voter(object):
-
     def __init__(self, connection):
 
         self.connection = connection
 
-    def voter_registration_check(self, first_name=None, last_name=None,
-                                 state=None, street_number=None,
-                                 street_name=None, city=None, zip_code=None,
-                                 age=None, dob=None, phone=None, email=None,
-                                 unparsed_full_address=None):
+    def voter_registration_check(
+        self,
+        first_name=None,
+        last_name=None,
+        state=None,
+        street_number=None,
+        street_name=None,
+        city=None,
+        zip_code=None,
+        age=None,
+        dob=None,
+        phone=None,
+        email=None,
+        unparsed_full_address=None,
+    ):
         """
         Searches for a registered individual, returns matches.
 
@@ -293,44 +361,45 @@ class Voter(object):
             age; int
                 Optional; One or more integers. Trailing wildcard allowed
             dob; str
-                Numeric characters in YYYYMMDD format. Trailing wildcard allowed
+                Optional; Numeric characters in YYYYMMDD format. Trailing wildcard allowed
             phone; str
-                Integer followed by 0 or more * or integers
+                Optional; Integer followed by 0 or more * or integers
             email: str
-                Alphanumeric character followed by 0 or more * or legal characters
+                Optional; Alphanumeric character followed by 0 or more * or legal characters
                 (alphanumeric, @, -, .)
             unparsed_full_address: str
-                One or more alphanumeric characters. No wildcards.
+                Optional; One or more alphanumeric characters. No wildcards.
         `Returns`
             Parsons Table
                 See :ref:`parsons-table` for output options.
         """
 
-        url = self.connection.uri + 'voter/voter-registration-check'
+        url = self.connection.uri + "voter/voter-registration-check"
 
         if None in [first_name, last_name, state]:
-            raise ValueError("""Function must include at least first_name,
-                             last_name, and state.""")
+            raise ValueError(
+                """Function must include at least first_name,
+                             last_name, and state."""
+            )
 
-        args = {'first_name': first_name,
-                'last_name': last_name,
-                'state': state,
-                'street_number': street_number,
-                'street_name': street_name,
-                'city': city,
-                'zip_code': zip_code,
-                'age': age,
-                'dob': dob,
-                'phone': phone,
-                'email': email,
-                'unparsed_full_address': unparsed_full_address
-                }
+        args = {
+            "first_name": first_name,
+            "last_name": last_name,
+            "state": state,
+            "street_number": street_number,
+            "street_name": street_name,
+            "city": city,
+            "zip_code": zip_code,
+            "age": age,
+            "dob": dob,
+            "phone": phone,
+            "email": email,
+            "unparsed_full_address": unparsed_full_address,
+        }
 
         return self.connection.request(url, args=args, raw=True)
 
 
-class TargetSmartAPI(Voter, Person, Service):
-
+class TargetSmartAPI(Voter, Person, Service, SmartMatch):
     def __init__(self, api_key=None):
-
         self.connection = TargetSmartConnector(api_key=api_key)
